<?php

/**
 * This is the model class for table "Building_Test".
 *
 * The followings are the available columns in table 'Building_Test':
 * @property string $BuildingName
 * @property string $Heading
 * @property string $Remark
 * @property string $FromDate
 * @property string $ToDate
 * @property string $Particulars
 * @property integer $Rate
 * @property integer $UnitArea
 * @property double $RateofInterest
 */
class BuildingTest extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return BuildingTest the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'Building_Test';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('BuildingName', 'required'),
			array('Rate, UnitArea', 'numerical', 'integerOnly'=>true),
			array('RateofInterest', 'numerical'),
			array('BuildingName, Heading, Remark, Particulars', 'length', 'max'=>50),
			array('FromDate, ToDate', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('BuildingName, Heading, Remark, FromDate, ToDate, Particulars, Rate', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'BuildingName' => 'Building Name',
			'Heading' => 'Heading',
			'Remark' => 'Remark',
			'FromDate' => 'From Date',
			'ToDate' => 'To Date',
			'Particulars' => 'Particulars',
			'Rate' => 'Rate',
			'UnitArea' => 'Unit Area',
			'RateofInterest' => 'Rateof Interest',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('BuildingName',$this->BuildingName,true);
		$criteria->compare('Heading',$this->Heading,true);
		$criteria->compare('Remark',$this->Remark,true);
		$criteria->compare('FromDate',$this->FromDate,true);
		$criteria->compare('ToDate',$this->ToDate,true);
		$criteria->compare('Particulars',$this->Particulars,true);
		$criteria->compare('Rate',$this->Rate);
		$criteria->compare('UnitArea',$this->UnitArea);
		$criteria->compare('RateofInterest',$this->RateofInterest);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
            
}